@@ -32,6 +32,7 @@ UCSlotsLayoutPrivate::UCSlotsLayoutPrivate()
     : QQuickItemPrivate()
     , mainSlot(Q_NULLPTR)
     , m_parentItem(Q_NULLPTR)
+    , mainSlotHeight(0)
     , maxSlotsHeight(0)
     , _q_cachedHeight(-1)
     , maxNumberOfLeadingSlots(1)
@@ -540,7 +541,10 @@ void UCSlotsLayoutPrivate::_q_relayout()
             qmlInfo(q) << "Invalid attached property!";
             return;
         }
-        mainSlot->setImplicitWidth(q->width() - totalSlotsWidth
+        //bug#1630167: set width instead of implicitWidth to avoid clashing with internal logic of the
+        //component which is inside the mainSlot (e.g. Column and positioners handle the implicit width
+        //themselves)
+        mainSlot->setWidth(q->width() - totalSlotsWidth
                                    - attachedProps->padding()->leading()
                                    - attachedProps->padding()->trailing()
                                    - padding.leading() - padding.trailing());
